%global with_python3 1

%global srcname Chameleon

Name:           python-chameleon
Version:        3.8.1
Release:        1%{?dist}
Summary:        XML-based template compiler

Group:          Development/Languages
License:        BSD
URL:            https://github.com/malthe/chameleon
Source0:        https://github.com/malthe/chameleon/archive/%{version}/chameleon-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python2-devel
# For docs
BuildRequires:  python-sphinx
# For tests to run
BuildRequires:  python-setuptools
BuildRequires:  python-lxml
BuildRequires:  python-zope-interface

%if 0%{?with_python3}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-sphinx
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-lxml
BuildRequires:  python%{python3_pkgversion}-zope-interface
%endif

%if 0%{?rhel} && 0%{?rhel} <= 6
BuildRequires:  python-unittest2
%endif

%if 0%{?rhel} && 0%{?rhel} < 6
BuildRequires:  python-elementtree
Requires:       python-elementtree
%endif

Requires: python-setuptools
Requires: python-zope-interface
Requires: python-lxml

%description
Chameleon is an XML attribute language template compiler. It comes with
implementations for the Zope Page Templates (ZPT) and Genshi templating
languages.

The engine compiles templates into Python byte-code. This results in
performance which is on average 10-15 times better than implementations which
use run-time interpretation.

%if 0%{?with_python3}
%package -n python%{python3_pkgversion}-chameleon
Summary:        XML-based template compiler
Group:          Development/Languages

Requires:   python%{python3_pkgversion}-setuptools
Requires:   python%{python3_pkgversion}-zope-interface
Requires:   python%{python3_pkgversion}-lxml
Provides:   python3-chameleon = %{version}-%{release}

%description -n python%{python3_pkgversion}-chameleon
Chameleon is an XML attribute language template compiler. It comes with
implementations for the Zope Page Templates (ZPT) and Genshi templating
languages.

The engine compiles templates into Python byte-code. This results in
performance which is on average 10-15 times better than implementations which
use run-time interpretation.
%endif

%prep
%autosetup -n chameleon-%{version}

%if 0%{?with_python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
%endif

%build
%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py build
popd
%endif

%{__python2} setup.py build

PYTHONPATH=`pwd`/src make html

%install
%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root=%{buildroot}
popd
%endif

%{__python2} setup.py install --skip-build --root %{buildroot}

# No need to ship docs and tests as part of the module
rm -rf %{buildroot}%{python2_sitelib}/chameleon/docs
rm -rf  %{buildroot}%{python2_sitelib}/chameleon/tests
# Data files for the tests
find %{buildroot}%{python2_sitelib}/chameleon -name '*.txt' -exec rm \{\} \;

# No need to ship docs and tests as part of the module
rm -rf %{buildroot}%{python3_sitelib}/chameleon/docs
rm -rf  %{buildroot}%{python3_sitelib}/chameleon/tests
# Data files for the tests
find %{buildroot}%{python3_sitelib}/chameleon -name '*.txt' -exec rm \{\} \;

# Clean up the documentation
mv _build/html .
rm -rf html/.buildinfo

%check
%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py test
popd
%endif

%{__python2} setup.py test

%files
%doc *.rst *.txt docs html
%{python2_sitelib}/chameleon/
%{python2_sitelib}/Chameleon-%{version}*

%if 0%{?with_python3}
%files -n python%{python3_pkgversion}-chameleon
%doc *.rst *.txt docs html
%{python3_sitelib}/chameleon/
%{python3_sitelib}/Chameleon-%{version}*
%endif

%changelog
* Sun Jan 10 2021 Kevin Fenzi <kevin@scrye.com> - 3.8.1-1
- Update to 3.8.1.
- Build python3 packages for epel7. rhbz#1789317

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.11-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jan 16 2013 Ralph Bean <rbean@redhat.com> - 2.11-1
- Latest upstream version.
- More specific file/dir ownership.
- Removed unnecessary buildroot.
- Removed unnecessary defattr.
- Removed unnecessary clean section.
- Packaging a python3 subpackage.

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.7.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Dec 13 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 2.7.0-1
- New upstream release

* Thu Nov 10 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 2.5.3-1.1
- Fix to build on RHEL6

* Thu Nov 10 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 2.5.3-1
- New upstream release

* Mon Oct 3 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 2.5.1-1
- New upstream release

* Sun Aug 21 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 2.3.8-1
- New upstream release

* Thu Aug 18 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 2.3.6-1
- New upstream release

* Wed Aug 10 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 2.2-1
- New upstream release

* Fri Jul 15 2011 Toshio Kuratomi <toshio@fedoraproject.org> - 2.0-1
- New upstream release
- This release removes the genshi-like syntax support -- F17+, only

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.12-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Sep 18 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.2.12-4
- Move COPYING file out of the ast directory and into docdir.

* Fri Sep 17 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.2.12-3
- Fix unittests on python-2.7.

* Thu Sep 16 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.2.12-2
- Add a patch so we can run with newer versions of the optional deps

* Wed Sep 15 2010 Toshio Kuratomi <toshio@fedoraproject.org> - 1.2.12-1
- Initial package
